pub enum Either25<A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T, U, V, W, X, Y> {
Show 25 variants A(A), B(B), C(C), D(D), E(E), F(F), G(G), H(H), I(I), J(J), K(K), L(L), M(M), N(N), O(O), P(P), Q(Q), R(R), S(S), T(T), U(U), V(V), W(W), X(X), Y(Y),
}

Variants



A(A)



B(B)



C(C)



D(D)



E(E)



F(F)



G(G)



H(H)



I(I)



J(J)



K(K)



L(L)



M(M)



N(N)



O(O)



P(P)



Q(Q)



R(R)



S(S)



T(T)



U(U)



V(V)



W(W)



X(X)



Y(Y)

Implementations

source

impl<A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T, U, V, W, X, Y> Either25<A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T, U, V, W, X, Y>where
    A: NapiRaw,
    B: NapiRaw,
    C: NapiRaw,
    D: NapiRaw,
    E: NapiRaw,
    F: NapiRaw,
    G: NapiRaw,
    H: NapiRaw,
    I: NapiRaw,
    J: NapiRaw,
    K: NapiRaw,
    L: NapiRaw,
    M: NapiRaw,
    N: NapiRaw,
    O: NapiRaw,
    P: NapiRaw,
    Q: NapiRaw,
    R: NapiRaw,
    S: NapiRaw,
    T: NapiRaw,
    U: NapiRaw,
    V: NapiRaw,
    W: NapiRaw,
    X: NapiRaw,
    Y: NapiRaw,

source

pub fn as_unknown(&self, env: Env) -> Unknown