pub struct ThreadsafeFunctionHandle { /* private fields */ }Implementations
Sourceimpl ThreadsafeFunctionHandle
impl ThreadsafeFunctionHandle
Sourcepub fn new(raw: napi_threadsafe_function) -> Arc<Self>
pub fn new(raw: napi_threadsafe_function) -> Arc<Self>
create a Arc to hold the ThreadsafeFunctionHandle
Sourcepub fn with_read_aborted<RT, F>(&self, f: F) -> RT
pub fn with_read_aborted<RT, F>(&self, f: F) -> RT
Lock aborted with read access, call f with the value of aborted, then unlock it
Sourcepub fn with_write_aborted<RT, F>(&self, f: F) -> RT
pub fn with_write_aborted<RT, F>(&self, f: F) -> RT
Lock aborted with write access, call f with the RwLockWriteGuard, then unlock it
pub fn null() -> Arc<Self>
pub fn get_raw(&self) -> napi_threadsafe_function
pub fn set_raw(&self, raw: napi_threadsafe_function)