Function

Struct Function 

pub struct Function<'scope, Args: JsValuesTupleIntoVec = Unknown<'scope>, Return = Unknown<'scope>> { /* private fields */ }
A JavaScript function. It can only live in the scope of a function call. If you want to use it outside the scope of a function call, you can turn it into a reference. By calling the create_ref method.

Implementations

Source

impl<Args: JsValuesTupleIntoVec, Return> Function<'_, Args, Return>

pub fn name(&self) -> Result<String>

Get the name of the JavaScript function.

pub fn create_ref(&self) -> Result<FunctionRef<Args, Return>>

Create a reference to the JavaScript function.

pub fn new_instance<'a>(&self, args: Args) -> Result<Unknown<'a>>

Create a new instance of the JavaScript Class.

pub fn build_threadsafe_function<T: 'static>( &self, ) -> ThreadsafeFunctionBuilder<'_, T, Args, Return>

Create a threadsafe function from the JavaScript function.

Source

impl<Args: JsValuesTupleIntoVec, Return: FromNapiValue> Function<'_, Args, Return>

pub fn call(&self, args: Args) -> Result<Return>

Call the JavaScript function. this in the JavaScript function will be undefined. If you want to specify this, you can use the apply method.

pub fn apply<Context: ToNapiValue>( &self, this: Context, args: Args, ) -> Result<Return>

Call the JavaScript function. this in the JavaScript function will be the provided this.

pub fn bind<T: ToNapiValue>( &self, this: T, ) -> Result<Function<'_, Args, Return>>

Call Function.bind