pub struct Function<'scope, Args: JsValuesTupleIntoVec = Unknown<'scope>, Return = Unknown<'scope>> { /* private fields */ }Expand description
A JavaScript function.
It can only live in the scope of a function call.
If you want to use it outside the scope of a function call, you can turn it into a reference.
By calling the create_ref method.
Implementations
Sourceimpl<Args: JsValuesTupleIntoVec, Return> Function<'_, Args, Return>
impl<Args: JsValuesTupleIntoVec, Return> Function<'_, Args, Return>
Sourcepub fn create_ref(&self) -> Result<FunctionRef<Args, Return>>
pub fn create_ref(&self) -> Result<FunctionRef<Args, Return>>
Create a reference to the JavaScript function.
Sourcepub fn new_instance<'a>(&self, args: Args) -> Result<Unknown<'a>>
pub fn new_instance<'a>(&self, args: Args) -> Result<Unknown<'a>>
Create a new instance of the JavaScript Class.
Sourcepub fn build_threadsafe_function<T: 'static>(
&self,
) -> ThreadsafeFunctionBuilder<'_, T, Args, Return>
pub fn build_threadsafe_function<T: 'static>( &self, ) -> ThreadsafeFunctionBuilder<'_, T, Args, Return>
Create a threadsafe function from the JavaScript function.
Sourceimpl<Args: JsValuesTupleIntoVec, Return: FromNapiValue> Function<'_, Args, Return>
impl<Args: JsValuesTupleIntoVec, Return: FromNapiValue> Function<'_, Args, Return>
Sourcepub fn call(&self, args: Args) -> Result<Return>
pub fn call(&self, args: Args) -> Result<Return>
Call the JavaScript function.
this in the JavaScript function will be undefined.
If you want to specify this, you can use the apply method.
Sourcepub fn apply<Context: ToNapiValue>(
&self,
this: Context,
args: Args,
) -> Result<Return>
pub fn apply<Context: ToNapiValue>( &self, this: Context, args: Args, ) -> Result<Return>
Call the JavaScript function.
this in the JavaScript function will be the provided this.
Sourcepub fn bind<T: ToNapiValue>(
&self,
this: T,
) -> Result<Function<'_, Args, Return>>
pub fn bind<T: ToNapiValue>( &self, this: T, ) -> Result<Function<'_, Args, Return>>
Call Function.bind